@@ -39,7 +39,3 @@ class DetectorReadoutError(Error):
     def __init__(self, txt):
         super(DetectorReadoutError, self).__init__(txt)
 
-class ParameterError(Error):
-    '''Error in the parameters of a recipe.'''
-    def __init__(self, txt):
-        super(ParameterError, self).__init__(txt)
\ No newline at end of file
